#!/usr/bin/perl -w

use strict;
use warnings;

use Data::Dumper;
use Getopt::Long;

if (!@ARGV) {
	system("perldoc $0");
	exit;
}
if ("@ARGV" eq "-h") {
	system("perldoc $0");
	exit;
}

my $opt = {};
GetOptions($opt,
	"help|h|?",
	"verbose|v",
	"output|o=s",
	"letter|l=s",
	"shape=s",
	"letter_colour|l_colour|letter_color|l_color=s",
	"shape_colour|s_colour|shape_color|s_color=s",
	);

if ($opt->{help}) {
	system("perldoc $0");
	exit;
}

my $verbose = $opt->{verbose};

my $defaults = {
	shape => 'square',
	shape_colour => '000000',
	letter_colour => 'FFFFFF',
};

my $shape_h = {
	rectangle => { tag => 'rect', coords => 'x="3.5" y="11.5" width="52" height="36"' },
	circle => { tag => 'circle', coords => 'cx="29.5" cy="29.5" r="25.6"' },
	diamond => { tag => 'rect', coords => 'x="8.3" y="8.301" transform="matrix(0.7071 -0.7071 0.7071 0.7071 -12.2193 29.4997)" width="42.399" height="42.398"'},
	square => { tag => 'rect', coords => 'x="7.5" y="7.5" width="44" height="44"'},
	r_arrow => { tag => 'polygon', coords => 'points="60,30 32,0 32,8 8,8 8,52 32,52 32,60"'},
	l_arrow => { tag => 'polygon', coords => 'points="8,30 36,60 36,52 60,52 60,8 36,8 36,0"'},
	up_arrow => { tag => 'polygon', coords => 'points="30,0 0,28 8,28 8,52 52,52 52,28 60,28"'},
	down_arrow => { tag => 'polygon', coords => 'points="52,32 52,8 8,8 8,32 0,32 30,60 60,32"'},
};

my @errs;
my $svg_data;

## check we have the letter
if (! defined $opt->{letter})
{	push @errs, "A letter must be specified.";
}
else # $opt->{letter} is defined
{	$svg_data->{letter} = svg_data($opt->{letter});
	if (! $svg_data->{letter} )
	{	push @errs, "The letter ".$opt->{letter}." could not be found.";
	}
}


## check the shape
if (! defined $opt->{shape})
{	# use the default shape
	$svg_data->{shape} = { id => $defaults->{shape}, %{$shape_h->{ $defaults->{shape}}} };
	print STDERR "Using default shape\n" if $verbose;
}
elsif (! $shape_h->{ lc $opt->{shape} })
{	push @errs, "The background shape ".$opt->{shape}." could not be found.";
}
else
{	$svg_data->{shape} = { id => lc $opt->{shape}, %{$shape_h->{ lc $opt->{shape} }}};
}

## we need all the options to be specified.
foreach my $o qw( letter shape )
{	if ($opt->{ $o."_colour" })
	{	# make sure that it is the right format
		# remove any non-digit chars
		$opt->{ $o."_colour" } =~ s/[^a-f\d]//ig;
		if ($opt->{ $o."_colour" } =~ /^([a-f\d])([a-f\d])([a-f\d])$/i)
		{	# double each number in the code
			$opt->{ $o."_colour" } = "$1$1$2$2$3$3";
		}
		elsif ($opt->{ $o."_colour" } =~ /[a-f\d]{6}/i)
		{	# chop off any extra digits
			$opt->{ $o."_colour" } =~ s/^([a-f\d]{6}).*/$1/i;
		}
		else
		{	push @errs, $o."_colour must be specified as a six digit html colour code";
			delete $opt->{ $o."_colour" };
		}
	}
	else
	{	$opt->{ $o."_colour" } = $defaults->{ $o."_colour" };
		print STDERR "Using the default $o colour\n";
	}
	
	# if the colour is OK and we have svg data for the shape, add the colour data
	if ($opt->{ $o."_colour" } && $svg_data->{$o})
	{	$svg_data->{$o}{colour} = $opt->{ $o."_colour" };
	}
}

# check that the shape and letter colours are different...
if ($opt->{letter_colour} && $opt->{shape_colour} && $opt->{letter_colour} eq $opt->{shape_colour})
{	push @errs, "The letter and background colours must be different!";
}

## check that the file name specified is OK
if (! defined $opt->{output})
{	## print to STDOUT instead
	print STDERR "No output specified; printing to STDOUT\n" if $verbose;
	$opt->{out} = \*STDOUT;
}
elsif ( -f $opt->{output} ) # if it already exists...
{	push @errs, "File ". $opt->{output}." already exists";
}
else
{	if (open FH, '>', $opt->{output})
	{	$opt->{out} = \*FH;
	}
	else
	{	push @errs, "Can't open ".$opt->{output}.": $!";
	}
}

if (! @errs)
{	# try opening the file...
	write_svg( $opt->{out}, $svg_data );
	close $opt->{out} if $opt->{output};
}
else
{	unshift @errs, "The following errors were found when trying to create an SVG:";
	die join("\n", @errs);
}

exit(0);


sub write_svg {
	my $out = shift;
	my $svg_data = shift;

	print $out
'<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<svg
   xmlns:svg="http://www.w3.org/2000/svg"
   xmlns="http://www.w3.org/2000/svg"
   version="1.0" width="60" height="60" viewBox="0 0 60 60"
   id="custom_svg"
   xml:space="preserve">
';

# print out the bg picture...
	print $out '
	<' . $svg_data->{shape}{tag} 
		. ' id="' . $svg_data->{shape}{id}
		. '" ' . $svg_data->{shape}{coords}
		. ' style="fill:#' . $svg_data->{shape}{colour} . '" />';

# print out the letter
	print $out '
	<path id="' . $svg_data->{letter}{id}
		. '" d="' . $svg_data->{letter}{d}
		. '" style="fill:#' . $svg_data->{letter}{colour} . '" />';

	print $out '
</svg>
';
}


sub svg_data {
	my $letter = shift;
	my $data = {
	
'a' => "M31.627,36.233c-1.734,1.676-3.592,2.514-5.572,2.514c-1.688,0-3.059-0.516-4.113-1.547s-1.582-2.367-1.582-4.008
		c0-2.133,0.853-3.776,2.558-4.931s4.146-1.731,7.321-1.731h1.389v-1.758c0-2.004-1.143-3.006-3.428-3.006
		c-2.027,0-4.078,0.574-6.152,1.723v-3.586c2.355-0.891,4.688-1.336,6.996-1.336c5.051,0,7.576,2.01,7.576,6.029v8.543
		c0,1.512,0.486,2.268,1.459,2.268c0.176,0,0.404-0.023,0.686-0.07l0.123,2.918c-1.102,0.328-2.074,0.492-2.918,0.492
		c-2.133,0-3.504-0.838-4.113-2.514H31.627z M31.627,33.438v-3.92h-1.23c-3.363,0-5.045,1.055-5.045,3.164
		c0,0.715,0.243,1.315,0.729,1.802s1.087,0.729,1.802,0.729C29.102,35.214,30.35,34.622,31.627,33.438z",
'b' => "M20.825,38.308V10.552h5.203v12.094c1.336-2.719,3.439-4.078,6.311-4.078c2.32,0,4.146,0.85,5.476,2.549
		s1.995,4.037,1.995,7.014c0,3.223-0.75,5.798-2.25,7.726s-3.504,2.892-6.012,2.892c-2.156,0-3.996-0.797-5.52-2.391l-0.967,1.951
		H20.825z M26.028,33.263c1.266,1.406,2.613,2.109,4.043,2.109c1.277,0,2.297-0.618,3.059-1.854s1.143-2.886,1.143-4.948
		c0-3.949-1.271-5.924-3.814-5.924c-1.535,0-3.012,0.99-4.43,2.971V33.263z",
'c' => "M37.41,37.886c-2.156,0.574-4.154,0.861-5.994,0.861c-3.082,0-5.517-0.905-7.304-2.716s-2.681-4.274-2.681-7.392
		c0-3.152,0.92-5.619,2.76-7.4s4.383-2.672,7.629-2.672c1.57,0,3.381,0.252,5.432,0.756v3.762c-2.133-0.691-3.838-1.037-5.115-1.037
		c-1.559,0-2.812,0.598-3.762,1.793s-1.424,2.783-1.424,4.764c0,2.027,0.513,3.65,1.538,4.869s2.394,1.828,4.104,1.828
		c1.559,0,3.164-0.34,4.816-1.02V37.886z",
'd' => "M32.972,38.308v-3.639c-1.336,2.719-3.439,4.078-6.311,4.078c-2.32,0-4.143-0.85-5.467-2.549s-1.986-4.037-1.986-7.014
		c0-3.234,0.747-5.812,2.241-7.734s3.501-2.883,6.021-2.883c2.016,0,3.85,0.797,5.502,2.391V10.552h5.221v27.756H32.972z
		 M32.972,24.052c-1.254-1.406-2.596-2.109-4.025-2.109c-1.277,0-2.297,0.615-3.059,1.846s-1.143,2.883-1.143,4.957
		c0,3.949,1.266,5.924,3.797,5.924c1.547,0,3.023-0.99,4.43-2.971V24.052z",
'e' => "M37.92,37.657c-2.473,0.727-4.816,1.09-7.031,1.09c-3.223,0-5.766-0.914-7.629-2.742s-2.795-4.324-2.795-7.488
		c0-2.988,0.853-5.394,2.558-7.216s3.958-2.733,6.759-2.733c2.824,0,4.887,0.891,6.188,2.672s1.951,4.6,1.951,8.455H25.949
		c0.352,3.68,2.373,5.52,6.064,5.52c1.746,0,3.715-0.404,5.906-1.213V37.657z M25.879,26.759h6.926c0-3.293-1.061-4.939-3.182-4.939
		C27.467,21.819,26.219,23.466,25.879,26.759z",
'f' => "M25.466,38.308V22.259h-2.654v-3.252h2.654v-1.389c0-5.004,2.373-7.506,7.119-7.506c1.535,0,3.117,0.223,4.746,0.668v3.516
		c-1.477-0.621-2.801-0.932-3.973-0.932c-1.793,0-2.689,1.354-2.689,4.061v1.582h4.887v3.252h-4.887v16.049H25.466z",
'g' => "M21.019,44.302l0.422-3.779c2.145,0.984,4.189,1.477,6.135,1.477c1.922,0,3.311-0.41,4.166-1.23s1.283-2.15,1.283-3.99
		v-2.637c-1.266,2.777-3.357,4.166-6.275,4.166c-2.297,0-4.119-0.858-5.467-2.575s-2.021-4.04-2.021-6.97
		c0-3.082,0.756-5.552,2.268-7.409s3.521-2.786,6.029-2.786c1.969,0,3.791,0.797,5.467,2.391l0.545-1.951h4.676v14.73
		c0,2.941-0.179,5.062-0.536,6.363s-1.052,2.408-2.083,3.322c-1.734,1.5-4.178,2.25-7.33,2.25
		C26.058,45.673,23.632,45.216,21.019,44.302z M33.024,31.118v-7.119c-1.254-1.418-2.566-2.127-3.938-2.127
		c-1.312,0-2.355,0.598-3.129,1.793s-1.16,2.801-1.16,4.816c0,3.773,1.213,5.66,3.639,5.66
		C30.112,34.142,31.642,33.134,33.024,31.118z",
'h' => "M20.931,38.308V10.552h5.203v12.094c1.699-2.719,3.891-4.078,6.574-4.078c1.723,0,3.082,0.545,4.078,1.635
		s1.494,2.578,1.494,4.465v13.641h-5.203V25.95c0-2.191-0.727-3.287-2.18-3.287c-1.652,0-3.24,1.166-4.764,3.498v12.146H20.931z",
'i' => "M26.898,15.755v-4.342h5.203v4.342H26.898z M26.898,38.308V19.007h5.203v19.301H26.898z",
'j' => "M21.933,44.864v-3.48c1.512,0.691,2.807,1.037,3.885,1.037c1.008,0,1.726-0.313,2.153-0.94s0.642-1.685,0.642-3.173V19.007
		h5.203v18.949c0,2.695-0.601,4.658-1.802,5.889s-3.12,1.846-5.757,1.846C25.085,45.69,23.644,45.415,21.933,44.864z M28.612,15.755
		v-4.342h5.203v4.342H28.612z",
'k' => "M21.361,38.308V10.552h5.203v17.455h0.334l6.873-9h4.324l-6.346,8.262l8.332,11.039h-6.328l-6.855-9.65h-0.334v9.65H21.361
		z",
'l' => "M26.898,38.308V10.552h5.203v27.756H26.898z",
'm' => "M15.297,38.308V19.007h4.992v3.639c1.523-2.719,3.691-4.078,6.504-4.078c1.453,0,2.648,0.357,3.586,1.072
		s1.512,1.717,1.723,3.006c1.805-2.719,3.984-4.078,6.539-4.078c3.527,0,5.291,1.945,5.291,5.836v13.904h-4.992V26.108
		c0-2.285-0.762-3.428-2.285-3.428c-1.559,0-3.076,1.125-4.553,3.375v12.252h-4.992V26.108c0-2.297-0.768-3.445-2.303-3.445
		s-3.041,1.131-4.518,3.393v12.252H15.297z",
'n' => "M20.931,38.308V19.007h5.203v3.639c1.699-2.719,3.891-4.078,6.574-4.078c1.723,0,3.082,0.545,4.078,1.635
		s1.494,2.578,1.494,4.465v13.641h-5.203V25.95c0-2.191-0.727-3.287-2.18-3.287c-1.652,0-3.24,1.166-4.764,3.498v12.146H20.931z",
'o' => "M29.359,38.747c-3.012,0-5.405-0.911-7.181-2.733s-2.663-4.274-2.663-7.356c0-3.117,0.894-5.578,2.681-7.383
		s4.216-2.707,7.286-2.707c3.082,0,5.517,0.902,7.304,2.707s2.681,4.254,2.681,7.348c0,3.164-0.896,5.643-2.689,7.436
		S32.512,38.747,29.359,38.747z M29.447,35.495c2.988,0,4.482-2.291,4.482-6.873c0-2.098-0.396-3.756-1.187-4.975
		s-1.878-1.828-3.261-1.828c-1.371,0-2.452,0.609-3.243,1.828s-1.187,2.889-1.187,5.01c0,2.098,0.393,3.762,1.178,4.992
		S28.088,35.495,29.447,35.495z",
'p' => "M20.825,45.251V19.007h5.203v3.639c1.336-2.719,3.439-4.078,6.311-4.078c2.32,0,4.146,0.85,5.476,2.549
		s1.995,4.037,1.995,7.014c0,3.234-0.75,5.812-2.25,7.734s-3.51,2.883-6.029,2.883c-2.027,0-3.861-0.797-5.502-2.391v8.895H20.825z
		 M26.028,33.263c1.266,1.406,2.613,2.109,4.043,2.109c1.277,0,2.297-0.618,3.059-1.854s1.143-2.886,1.143-4.948
		c0-3.949-1.271-5.924-3.814-5.924c-1.535,0-3.012,0.99-4.43,2.971V33.263z",
'q' => "M32.972,45.251V34.669c-1.336,2.719-3.439,4.078-6.311,4.078c-2.32,0-4.143-0.85-5.467-2.549s-1.986-4.037-1.986-7.014
		c0-3.234,0.747-5.812,2.241-7.734s3.501-2.883,6.021-2.883c2.016,0,3.85,0.797,5.502,2.391l0.65-1.951h4.57v26.244H32.972z
		 M32.972,24.052c-1.254-1.406-2.596-2.109-4.025-2.109c-1.277,0-2.297,0.615-3.059,1.846s-1.143,2.883-1.143,4.957
		c0,3.949,1.266,5.924,3.797,5.924c1.547,0,3.023-0.99,4.43-2.971V24.052z",
'r' => "M24.569,38.308V19.007h5.203v3.639c1.348-2.719,3.398-4.078,6.152-4.078c0.328,0,0.65,0.035,0.967,0.105v4.641
		c-0.738-0.27-1.424-0.404-2.057-0.404c-2.074,0-3.762,1.049-5.062,3.146v12.252H24.569z",
's' => "M22.064,37.692v-3.814c2.578,1.078,4.781,1.617,6.609,1.617c2.133,0,3.199-0.727,3.199-2.18
		c0-0.938-0.879-1.758-2.637-2.461l-1.758-0.703c-1.91-0.773-3.275-1.605-4.096-2.496s-1.23-1.992-1.23-3.305
		c0-1.828,0.697-3.249,2.092-4.263s3.346-1.521,5.854-1.521c1.57,0,3.439,0.229,5.607,0.686v3.656
		c-2.086-0.727-3.814-1.09-5.186-1.09c-2.156,0-3.234,0.668-3.234,2.004c0,0.879,0.797,1.623,2.391,2.232l1.512,0.58
		c2.262,0.855,3.835,1.723,4.72,2.602s1.327,2.01,1.327,3.393c0,1.816-0.753,3.29-2.259,4.421s-3.466,1.696-5.88,1.696
		C26.775,38.747,24.432,38.396,22.064,37.692z",
't' => "M35.406,38.202c-1.242,0.363-2.221,0.545-2.936,0.545c-4.512,0-6.768-2.109-6.768-6.328v-10.16h-2.162v-3.252h2.162v-3.252
		l5.203-0.598v3.85h4.131v3.252h-4.131v9.475c0,2.367,0.967,3.551,2.9,3.551c0.445,0,0.979-0.082,1.6-0.246V38.202z",
'u' => "M32.866,38.308v-3.639c-1.688,2.719-3.879,4.078-6.574,4.078c-1.723,0-3.082-0.545-4.078-1.635s-1.494-2.578-1.494-4.465
		V19.007h5.203v12.357c0,2.191,0.732,3.287,2.197,3.287c1.641,0,3.223-1.166,4.746-3.498V19.007h5.203v19.301H32.866z",
'v' => "M26.837,38.308l-7.365-19.301h5.484l5.396,13.922l5.361-13.922h3.762L32.04,38.308H26.837z",
'w' => "M20.632,38.308l-5.361-19.301h4.834l3.797,13.518l4.043-13.518h4.5l3.639,13.588l4.096-13.588H43.8l-5.73,19.301h-4.992
		l-3.516-13.236l-3.938,13.236H20.632z",
'x' => "M20.061,38.308l6.627-9.686l-6.346-9.615h5.924l4.148,6.117l3.973-6.117h4.219l-6.047,9.475l6.486,9.826h-5.924
		l-4.324-6.381l-4.43,6.381H20.061z",
'y' => "M22.328,45.251l4.377-6.943l-7.154-19.301h5.59l4.781,12.902L35.6,19.007h3.955L27.637,45.251H22.328z",
'z' => "M21.027,38.308v-3.463L31.82,22.259H21.52v-3.252h16.453v3.252L27.18,34.845h11.004v3.463H21.027z",
'A_UC' => "M16.65,38.276l10.125-26.016h5.414l10.125,26.016H36.76l-2.707-6.943H23.295l-2.707,6.943H16.65z M24.631,27.87h8.086
		l-4.043-10.371L24.631,27.87z",
'B_UC' => "M21.414,38.276V12.261h8.842c2.613,0,4.603,0.492,5.968,1.477s2.048,2.42,2.048,4.307c0,3.129-2.08,5.344-6.24,6.645
		c4.863,1.184,7.295,3.568,7.295,7.154c0,2.074-0.712,3.665-2.136,4.772s-3.466,1.661-6.126,1.661H21.414z M26.512,23.089h1.283
		c1.523,0,2.733-0.375,3.63-1.125s1.345-1.77,1.345-3.059c0-1.195-0.36-2.007-1.081-2.435s-2.083-0.642-4.087-0.642h-1.09V23.089z
		 M26.512,34.585h1.16c2.273,0,3.841-0.243,4.702-0.729s1.292-1.374,1.292-2.663c0-1.324-0.577-2.426-1.731-3.305
		s-2.61-1.318-4.368-1.318h-1.055V34.585z",
'C_UC' => "M40.864,37.271c-2.52,1.125-5.525,1.688-9.018,1.688c-4.266,0-7.588-1.201-9.967-3.604s-3.568-5.754-3.568-10.055
		c0-4.383,1.198-7.755,3.595-10.116s5.815-3.542,10.257-3.542c2.836,0,5.654,0.334,8.455,1.002v4.236
		c-3.176-1.113-5.836-1.67-7.98-1.67c-2.742,0-4.857,0.87-6.346,2.61s-2.232,4.21-2.232,7.409c0,3.141,0.8,5.59,2.399,7.348
		s3.823,2.637,6.671,2.637c2.555,0,5.133-0.645,7.734-1.934V37.271z",
'D_UC' => "M18.479,38.276V12.261h11.197c4.031,0,7.119,1.069,9.264,3.208s3.217,5.224,3.217,9.255c0,4.289-1.137,7.62-3.41,9.993
		s-5.455,3.56-9.545,3.56H18.479z M23.893,34.585h4.043c2.848,0,4.972-0.788,6.372-2.364s2.101-3.97,2.101-7.181
		c0-2.484-0.562-4.553-1.688-6.205c-0.773-1.137-1.705-1.922-2.795-2.355s-2.678-0.65-4.764-0.65h-3.27V34.585z",
'E_UC' => "M21.941,38.276V12.261h16.26v3.568H27.355v7.26h8.895v3.48h-8.895v8.016h11.672v3.691H21.941z",
'F_UC' => "M22.416,38.276V12.261h16.365v3.568H27.83v7.91h9v3.586h-9v10.951H22.416z",
'G_UC' => "M40.108,37.692c-3.258,0.844-6.07,1.266-8.438,1.266c-4.488,0-7.937-1.181-10.345-3.542s-3.612-5.745-3.612-10.151
		c0-4.371,1.204-7.734,3.612-10.09s5.839-3.533,10.292-3.533c2.848,0,5.672,0.334,8.473,1.002v4.236
		c-3.246-1.113-5.912-1.67-7.998-1.67c-2.754,0-4.881,0.879-6.381,2.637s-2.25,4.248-2.25,7.471c0,3.117,0.803,5.563,2.408,7.339
		s3.82,2.663,6.645,2.663c0.621,0,1.348-0.088,2.18-0.264v-8.561h5.414V37.692z",
'H_UC' => "M18.707,38.276V12.261h5.414v10.564h10.758V12.261h5.414v26.016h-5.414V26.411H24.121v11.865H18.707z",
'I_UC' => "M26.784,38.276V12.261h5.414v26.016H26.784z",
'J_UC' => "M21.388,42.847l-0.035-3.867c1.406,0.551,2.854,0.826,4.342,0.826c1.242,0,2.098-0.346,2.566-1.037
		s0.703-1.934,0.703-3.727V12.261h5.432v22.201c0,3.199-0.65,5.502-1.951,6.908s-3.428,2.109-6.381,2.109
		C24.587,43.479,23.028,43.269,21.388,42.847z",
'K_UC' => "M19.973,38.276V12.261h5.203v12.621l9.949-12.621h4.5l-9.018,11.672l11.197,14.344h-6.768l-9.861-12.797v12.797H19.973z",
'L_UC' => "M22.284,38.276V12.261h5.414v22.324h11.725v3.691H22.284z",
'M_UC' => "M16.413,38.276V12.261h7.172l6.258,18.299l6.451-18.299h6.293v26.016h-4.992V18.642l-6.346,17.895H26.89l-6.223-18.158
		v19.898H16.413z",
'N_UC' => "M18.918,38.276V12.261h4.764L35.74,30.032V12.261h4.342v26.016H35.23L23.26,20.505v17.771H18.918z",
'O_UC' => "M29.342,38.958c-3.949,0-7.107-1.242-9.475-3.727s-3.551-5.795-3.551-9.932c0-4.184,1.189-7.506,3.568-9.967
		s5.59-3.691,9.633-3.691c4.02,0,7.222,1.23,9.606,3.691s3.577,5.766,3.577,9.914c0,4.242-1.192,7.588-3.577,10.037
		S33.479,38.958,29.342,38.958z M29.412,35.372c2.32,0,4.157-0.911,5.511-2.733s2.03-4.292,2.03-7.409
		c0-3.023-0.68-5.449-2.039-7.277s-3.158-2.742-5.396-2.742c-2.262,0-4.069,0.914-5.423,2.742s-2.03,4.271-2.03,7.33
		c0,3.035,0.674,5.476,2.021,7.321S27.209,35.372,29.412,35.372z",
'P_UC' => "M21.713,38.276V12.261h9.07c3.164,0,5.423,0.53,6.776,1.591s2.03,2.833,2.03,5.317c0,2.812-0.905,5.001-2.716,6.565
		s-4.345,2.347-7.603,2.347h-2.25v10.195H21.713z M27.021,24.513h1.055c1.852,0,3.313-0.431,4.386-1.292s1.608-2.03,1.608-3.507
		c0-2.59-1.646-3.885-4.939-3.885h-2.109V24.513z",
'Q_UC' => "M41.709,43.511c-4.664-1.23-8.461-2.777-11.391-4.641c-0.855,0.059-1.488,0.088-1.898,0.088
		c-3.938,0-7.09-1.242-9.457-3.727s-3.551-5.795-3.551-9.932c0-4.184,1.189-7.506,3.568-9.967s5.59-3.691,9.633-3.691
		c4.043,0,7.25,1.233,9.624,3.7s3.561,5.804,3.561,10.011c0,5.906-2.314,10.025-6.943,12.357c3.41,1.172,6.867,1.945,10.371,2.32
		L41.709,43.511z M28.525,35.372c2.309,0,4.139-0.908,5.493-2.725s2.031-4.283,2.031-7.4c0-3.035-0.678-5.467-2.031-7.295
		s-3.154-2.742-5.405-2.742c-2.262,0-4.069,0.914-5.423,2.742s-2.03,4.271-2.03,7.33c0,3.035,0.674,5.476,2.021,7.321
		S26.31,35.372,28.525,35.372z",
'R_UC' => "M20.333,38.276V12.261h9.738c5.285,0,7.928,2.15,7.928,6.451c0,1.605-0.448,3.067-1.345,4.386s-2.13,2.329-3.7,3.032
		l8.508,12.146H34.87l-6.451-10.635h-2.988v10.635H20.333z M25.431,24.073h1.248c3.926,0,5.889-1.588,5.889-4.764
		c0-2.32-1.752-3.48-5.256-3.48h-1.881V24.073z",
'S_UC' => "M21.01,38.079v-4.465c2.801,1.172,5.197,1.758,7.189,1.758c1.395,0,2.493-0.311,3.296-0.932s1.204-1.465,1.204-2.531
		c0-0.844-0.252-1.556-0.756-2.136s-1.459-1.269-2.865-2.065l-1.74-0.967c-2.332-1.312-3.979-2.569-4.939-3.771
		s-1.441-2.604-1.441-4.21c0-2.145,0.788-3.867,2.364-5.168s3.659-1.951,6.249-1.951c2.074,0,4.412,0.299,7.014,0.896v4.166
		c-2.66-0.996-4.764-1.494-6.311-1.494c-1.195,0-2.153,0.267-2.874,0.8s-1.081,1.233-1.081,2.101c0,0.715,0.252,1.342,0.756,1.881
		s1.453,1.201,2.848,1.986l1.863,1.037c2.508,1.406,4.236,2.701,5.186,3.885s1.424,2.625,1.424,4.324
		c0,2.414-0.896,4.307-2.689,5.678s-4.266,2.057-7.418,2.057C26.201,38.958,23.775,38.665,21.01,38.079z",
'T_UC' => "M26.784,38.276V15.829h-9.316v-3.568h24.064v3.568h-9.316v22.447H26.784z",
'U_UC' => "M19.287,12.261h5.414v15.943c0,2.52,0.416,4.339,1.248,5.458s2.174,1.679,4.025,1.679c1.77,0,3.05-0.533,3.841-1.6
		s1.187-2.783,1.187-5.15v-16.33h4.711v15.979c0,2.402-0.229,4.233-0.686,5.493s-1.289,2.353-2.496,3.278
		c-1.652,1.277-3.873,1.916-6.662,1.916c-2.988,0-5.391-0.68-7.207-2.039c-1.254-0.938-2.13-2.048-2.628-3.331
		s-0.747-3.073-0.747-5.37V12.261z",
'V_UC' => "M26.978,38.276l-9.615-26.016h5.783l7.453,20.127l7.207-20.127h3.902l-9.299,26.016H26.978z",
'W_UC' => "M20.087,38.276l-6.486-26.016h5.115l4.746,19.037l4.482-19.037h4.518l4.254,18.932l4.992-18.932h3.744l-6.82,26.016h-5.168
		l-4.008-17.842l-4.201,17.842H20.087z",
'X_UC' => "M18.355,38.276l8.332-12.814l-7.963-13.201h6.311l5.291,8.754l5.73-8.754h4.377l-7.98,12.27l8.262,13.746h-6.293
		l-5.643-9.299l-6.047,9.299H18.355z",
'Y_UC' => "M26.582,38.276V27.378l-8.736-15.117h5.977l6.346,10.986l6.627-10.986h4.289l-9.088,15.082v10.934H26.582z",
'Z_UC' => "M19.762,38.276v-3.691l12.938-18.756H20.5v-3.568h18.492v3.568L26.055,34.585h12.938v3.691H19.762z",
'1' => "M22.688,38.308v-3.041h5.203V16.071l-5.203,1.301v-3.129l10.424-2.602v23.625h5.203v3.041H22.688z",
'2' => "M20.21,38.308v-4.113l0.281-0.387c1.395-1.863,2.824-3.434,4.289-4.711l2.127-1.881c3.504-3.094,5.256-5.807,5.256-8.139
		c0-2.719-1.547-4.078-4.641-4.078c-1.91,0-4.125,0.645-6.645,1.934v-3.814c2.648-0.984,5.209-1.477,7.682-1.477
		c2.766,0,4.98,0.653,6.645,1.96s2.496,3.056,2.496,5.247c0,1.512-0.404,2.889-1.213,4.131s-2.232,2.684-4.271,4.324l-1.758,1.406
		c-2.449,1.969-3.902,3.797-4.359,5.484h11.496v4.113H20.21z",
'3' => "M21.177,38.114v-3.902c2.578,0.996,4.705,1.494,6.381,1.494c1.559,0,2.81-0.398,3.753-1.195s1.415-1.857,1.415-3.182
		c0-3.434-2.514-5.15-7.541-5.15h-1.6v-3.111l1.354-0.018c4.711,0,7.066-1.541,7.066-4.623c0-2.355-1.453-3.533-4.359-3.533
		c-1.91,0-3.949,0.486-6.117,1.459v-3.551c2.285-0.785,4.693-1.178,7.225-1.178c2.684,0,4.784,0.551,6.302,1.652
		s2.276,2.625,2.276,4.57c0,3.07-1.916,5.238-5.748,6.504c4.383,1.008,6.574,3.352,6.574,7.031c0,2.332-0.879,4.178-2.637,5.537
		s-4.148,2.039-7.172,2.039C25.782,38.958,23.392,38.677,21.177,38.114z",
'4' => "M31.46,38.276v-6.943H19.313v-3.902l11.936-15.17h4.764v15.17h3.041v3.902h-3.041v6.943H31.46z M23.479,27.431h8.086
		V17.235L23.479,27.431z",
'5' => "M22.091,38.171v-3.779c2.215,0.855,4.061,1.283,5.537,1.283c1.488,0,2.669-0.442,3.542-1.327s1.31-2.083,1.31-3.595
		c0-3.727-2.678-5.59-8.033-5.59c-0.633,0-1.266,0.053-1.898,0.158V12.261h14.941v4.113H26.345l-0.264,5.607
		c3.75,0,6.677,0.768,8.78,2.303s3.155,3.68,3.155,6.434c0,2.543-0.92,4.547-2.76,6.012s-4.359,2.197-7.559,2.197
		C26.339,38.927,24.47,38.675,22.091,38.171z",
'6' => "M24.851,24.509c1.629-1.969,3.715-2.953,6.258-2.953c2.32,0,4.242,0.765,5.766,2.294s2.285,3.46,2.285,5.792
		c0,2.73-0.879,4.966-2.637,6.706s-4.02,2.61-6.785,2.61c-3.234,0-5.76-1.151-7.576-3.454s-2.725-5.505-2.725-9.606
		c0-4.512,1.034-8.019,3.103-10.521s4.972-3.753,8.71-3.753c1.758,0,3.938,0.316,6.539,0.949v3.797
		c-2.367-0.996-4.488-1.494-6.363-1.494c-2.086,0-3.703,0.844-4.852,2.531S24.851,21.462,24.851,24.509z M33.956,30.503
		c0-1.77-0.39-3.17-1.169-4.201s-1.837-1.547-3.173-1.547c-1.277,0-2.353,0.469-3.226,1.406s-1.31,2.098-1.31,3.48
		c0,1.816,0.428,3.281,1.283,4.395s1.975,1.67,3.357,1.67c1.289,0,2.317-0.472,3.085-1.415S33.956,32.085,33.956,30.503z",
'7' => "M23.022,38.276c0.246-1.957,0.729-3.674,1.45-5.15s2.341-4.055,4.86-7.734l6.117-8.912H21.915v-4.219h17.789v4.219
		c-3.41,4.301-6.082,8.382-8.016,12.243s-2.9,7.046-2.9,9.554H23.022z",
'8' => "M25.325,24.368c-2.508-1.652-3.762-3.645-3.762-5.977c0-2.016,0.791-3.647,2.373-4.896s3.656-1.872,6.223-1.872
		c2.414,0,4.345,0.533,5.792,1.6s2.171,2.49,2.171,4.271c0,2.297-1.465,4.471-4.395,6.521c3.703,1.934,5.555,4.365,5.555,7.295
		c0,2.285-0.902,4.131-2.707,5.537s-4.172,2.109-7.102,2.109c-2.801,0-5.06-0.645-6.776-1.934s-2.575-2.988-2.575-5.098
		C20.122,28.868,21.856,26.349,25.325,24.368z M27.892,26.108c-1.887,1.57-2.83,3.229-2.83,4.975c0,1.359,0.472,2.479,1.415,3.357
		s2.142,1.318,3.595,1.318c1.277,0,2.347-0.346,3.208-1.037s1.292-1.553,1.292-2.584c0-0.891-0.29-1.652-0.87-2.285
		s-1.708-1.424-3.384-2.373L27.892,26.108z M31.021,22.54c1.734-1.348,2.602-2.789,2.602-4.324c0-1.008-0.357-1.813-1.072-2.417
		s-1.658-0.905-2.83-0.905c-1.09,0-1.972,0.264-2.646,0.791s-1.011,1.219-1.011,2.074c0,0.844,0.334,1.585,1.002,2.224
		S29.052,21.474,31.021,22.54z",
'9' => "M21.282,38.114v-3.762c2.215,0.902,4.283,1.354,6.205,1.354c2.051,0,3.671-0.853,4.86-2.558s1.784-4.028,1.784-6.97
		c-1.652,1.98-3.691,2.971-6.117,2.971c-2.285,0-4.207-0.791-5.766-2.373s-2.338-3.533-2.338-5.854c0-2.707,0.882-4.931,2.646-6.671
		s4.017-2.61,6.759-2.61c3.211,0,5.728,1.143,7.55,3.428s2.733,5.438,2.733,9.457c0,4.5-1.072,8.03-3.217,10.591
		s-5.104,3.841-8.877,3.841C25.899,38.958,23.825,38.677,21.282,38.114z M25.114,20.114c0,1.805,0.39,3.229,1.169,4.271
		s1.837,1.564,3.173,1.564c1.266,0,2.332-0.475,3.199-1.424s1.301-2.115,1.301-3.498c0-1.84-0.425-3.322-1.274-4.447
		s-1.966-1.688-3.349-1.688c-1.289,0-2.314,0.469-3.076,1.406S25.114,18.509,25.114,20.114z",
'0' => "M29.386,38.958c-2.953,0-5.353-1.266-7.198-3.797s-2.769-5.818-2.769-9.861c0-4.09,0.926-7.389,2.777-9.896
		s4.289-3.762,7.312-3.762c3,0,5.429,1.251,7.286,3.753s2.786,5.78,2.786,9.835c0,4.16-0.929,7.488-2.786,9.984
		S32.468,38.958,29.386,38.958z M29.438,35.706c3.082,0,4.623-3.469,4.623-10.406s-1.518-10.406-4.553-10.406
		s-4.553,3.463-4.553,10.389C24.956,32.231,26.45,35.706,29.438,35.706z",
'1_UC' => "M27.76,30.911l-0.861-13.447v-5.203h5.203v5.203L31.24,30.911H27.76z M26.898,38.276v-4.342h5.203v4.342H26.898z",
'2_UC' => "M35.951,41.823v3.111c-1.969,0.492-3.762,0.738-5.379,0.738c-4.641,0-8.364-1.471-11.171-4.412s-4.21-6.838-4.21-11.689
		c0-4.898,1.518-9.006,4.553-12.322s6.797-4.975,11.285-4.975c3.938,0,7.107,1.345,9.51,4.034s3.604,6.237,3.604,10.644
		c0,3.258-0.604,5.821-1.811,7.69s-2.865,2.804-4.975,2.804c-1.113,0-1.992-0.264-2.637-0.791s-1.207-1.453-1.688-2.777
		c-1.828,2.379-3.697,3.568-5.607,3.568c-1.699,0-3.035-0.601-4.008-1.802s-1.459-2.856-1.459-4.966
		c0-3.141,0.838-5.689,2.514-7.646s3.855-2.936,6.539-2.936c0.867,0,2.549,0.105,5.045,0.316v9.053l0.035,1.635
		c0,2.273,0.645,3.41,1.934,3.41c2.016,0,3.023-2.396,3.023-7.189c0-3.551-0.926-6.431-2.777-8.64s-4.271-3.313-7.26-3.313
		c-3.504,0-6.501,1.371-8.991,4.113s-3.735,6.041-3.735,9.896c0,3.914,1.154,7.096,3.463,9.545s5.303,3.674,8.982,3.674
		C32.266,42.597,34.006,42.339,35.951,41.823z M32.154,23.349c-0.562-0.223-1.102-0.334-1.617-0.334c-3.047,0-4.57,2.361-4.57,7.084
		c0,2.766,0.826,4.148,2.479,4.148c1.113,0,2.35-1.119,3.709-3.357V23.349z",
'3_UC' => "M21.968,38.308v-4.113c1.289-0.305,2.188-0.823,2.698-1.556s0.765-1.866,0.765-3.401v-3.182h-2.865v-3.252h2.865v-2.988
		c0-5.461,2.631-8.191,7.893-8.191c1.406,0,2.971,0.141,4.693,0.422v3.568c-1.406-0.48-2.76-0.721-4.061-0.721
		c-2.215,0-3.322,1.254-3.322,3.762v4.148h3.428v3.252h-3.428c0,2.309-0.24,3.976-0.721,5.001s-1.506,2.071-3.076,3.138H38.28v4.113
		H21.968z",
'4_UC' => "M28.313,41.12v-2.883c-1.957,0-4.33-0.434-7.119-1.301v-3.832c2.613,1.184,4.986,1.834,7.119,1.951v-8.35l-0.896-0.615
		c-2.156-1.453-3.609-2.681-4.359-3.683s-1.125-2.218-1.125-3.647c0-1.746,0.571-3.199,1.714-4.359s2.698-1.857,4.667-2.092V9.462
		h2.83v2.848c1.84,0.094,3.703,0.463,5.59,1.107v3.533c-1.922-0.902-3.785-1.436-5.59-1.6v7.875l0.791,0.527
		c2.215,1.418,3.712,2.631,4.491,3.639s1.169,2.238,1.169,3.691c0,1.898-0.577,3.489-1.731,4.772s-2.728,2.083-4.72,2.399v2.865
		H28.313z M28.858,21.749v-6.258c-1.617,0.539-2.426,1.5-2.426,2.883C26.433,19.593,27.241,20.718,28.858,21.749z M30.599,34.845
		c1.676-0.527,2.514-1.559,2.514-3.094c0-1.172-0.838-2.355-2.514-3.551V34.845z",
'5_UC' => "M21.959,25.3c-1.887,0-3.378-0.583-4.474-1.749s-1.644-2.751-1.644-4.755c0-2.027,0.551-3.618,1.652-4.772
		s2.613-1.731,4.535-1.731c1.91,0,3.416,0.577,4.518,1.731s1.652,2.739,1.652,4.755c0,2.039-0.551,3.636-1.652,4.79
		S23.916,25.3,21.959,25.3z M17.512,38.958l20.461-27.316h3.516L21.045,38.958H17.512z M21.994,22.698
		c1.535,0,2.303-1.307,2.303-3.92c0-2.59-0.756-3.885-2.268-3.885c-1.523,0-2.285,1.301-2.285,3.902S20.494,22.698,21.994,22.698z
		 M36.918,38.308c-1.887,0-3.378-0.583-4.474-1.749s-1.644-2.751-1.644-4.755c0-2.027,0.551-3.618,1.652-4.772
		s2.613-1.731,4.535-1.731s3.431,0.577,4.526,1.731s1.644,2.739,1.644,4.755c0,2.051-0.551,3.65-1.652,4.799
		S38.875,38.308,36.918,38.308z M36.953,35.706c1.535,0,2.303-1.307,2.303-3.92c0-2.59-0.756-3.885-2.268-3.885
		c-1.523,0-2.285,1.301-2.285,3.902S35.453,35.706,36.953,35.706z",
'6_UC' => "M39.897,31.364h-3.393l-6.996-13.992h-0.035l-6.996,13.992h-3.393l10.406-20.812L39.897,31.364z",
'7_UC' => "M41.005,38.308h-6.117l-1.16-1.389c-2.051,1.359-4.307,2.039-6.768,2.039c-2.801,0-5.112-0.785-6.935-2.355
		s-2.733-3.562-2.733-5.977c0-3.586,2.162-6.27,6.486-8.051c-1.242-2.18-1.863-3.961-1.863-5.344c0-1.582,0.688-2.912,2.065-3.99
		s3.085-1.617,5.124-1.617c1.957,0,3.568,0.519,4.834,1.556s1.898,2.358,1.898,3.964c0,2.496-1.916,4.635-5.748,6.416
		c1.488,2.754,3.246,5.355,5.273,7.805c1.184-1.711,1.775-4.096,1.775-7.154v-0.404h4.377c0,3.832-1.383,7.23-4.148,10.195
		C38.515,35.489,39.728,36.925,41.005,38.308z M25.554,25.265c-2.145,0.973-3.217,2.443-3.217,4.412
		c0,1.652,0.536,3.053,1.608,4.201s2.382,1.723,3.929,1.723c1.359,0,2.619-0.41,3.779-1.23c-1.934-2.449-3.756-5.127-5.467-8.033
		L25.554,25.265z M28.454,21.134c2.027-1.078,3.041-2.373,3.041-3.885c0-1.57-0.773-2.355-2.32-2.355s-2.32,0.756-2.32,2.268
		C26.854,18.181,27.388,19.505,28.454,21.134z",
'8_UC' => "M27.733,19.257l-5.115-0.633l1.178-3.604l4.5,2.496c-0.387,0.422-0.58,0.885-0.58,1.389
		C27.716,18.987,27.722,19.104,27.733,19.257z M29.333,20.663l-2.197,4.676l-3.059-2.232l3.762-3.533
		C28.167,20.171,28.665,20.534,29.333,20.663z M27.593,12.261h3.797l-0.967,5.062c-0.316-0.152-0.627-0.229-0.932-0.229
		s-0.609,0.076-0.914,0.229L27.593,12.261z M31.161,19.573l3.762,3.533l-3.076,2.232l-2.18-4.676
		C30.323,20.534,30.821,20.171,31.161,19.573z M30.687,17.517l4.518-2.496l1.16,3.604l-5.115,0.633
		c0.023-0.152,0.035-0.27,0.035-0.352C31.284,18.401,31.085,17.938,30.687,17.517z",
'9_UC' => "M34.431,10.341v3.357c-3.117,3.141-4.676,7.582-4.676,13.324c0,5.754,1.559,10.201,4.676,13.342v3.357
		c-2.848-1.535-5.133-3.826-6.855-6.873s-2.584-6.322-2.584-9.826s0.847-6.756,2.54-9.756S31.524,11.958,34.431,10.341z",
'0_UC' => "M31.469,17.267c1.693,3,2.54,6.252,2.54,9.756s-0.861,6.779-2.584,9.826s-4.008,5.338-6.855,6.873v-3.357
		c3.117-3.141,4.676-7.588,4.676-13.342c0-5.742-1.559-10.184-4.676-13.324v-3.357C27.476,11.958,29.775,14.267,31.469,17.267z",
'minus' => "M21.467,28.731v-3.252h16.049v3.252H21.467z",
'plus' => "M27.979,38.308v-8.895h-8.895v-3.041h8.895v-8.877h3.041v8.877h8.877v3.041h-8.877v8.895H27.979z",

'greek_capital_alpha' => "M16.668,38.275L26.793,12.26h5.414l10.125,26.016h-5.556l-2.707-6.942H23.313l-2.707,6.942H16.668
	z M24.649,27.87h8.086l-4.043-10.371L24.649,27.87z",
'greek_capital_beta' => "M20.544,38.275V12.261h8.842c2.612,0,4.603,0.492,5.967,1.477c1.365,0.985,2.049,2.42,2.049,4.307
	c0,3.129-2.08,5.344-6.24,6.645c4.863,1.184,7.295,3.568,7.295,7.154c0,2.074-0.712,3.665-2.136,4.772
	c-1.424,1.106-3.466,1.661-6.126,1.661h-9.65V38.275z M25.641,23.089h1.283c1.522,0,2.732-0.375,3.63-1.125
	c0.896-0.75,1.345-1.77,1.345-3.059c0-1.195-0.36-2.007-1.081-2.436c-0.721-0.428-2.083-0.642-4.087-0.642h-1.09V23.089z
	 M25.641,34.585h1.16c2.272,0,3.841-0.243,4.702-0.729c0.86-0.485,1.292-1.373,1.292-2.662c0-1.324-0.577-2.426-1.731-3.305
	c-1.154-0.879-2.61-1.318-4.368-1.318h-1.055V34.585z",
'greek_capital_gamma' => "M21.581,38.275V12.261h15.838v3.674H26.994v22.342h-5.413V38.275z",
'greek_capital_delta' => "M16.844,38.275v-4.342L27.18,12.26h4.605l10.371,21.674v4.342H16.844z M28.621,17.956
	L21.01,33.936h15.259L28.621,17.956z",
'greek_capital_epsilon' => "M20.957,38.275V12.261h16.26v3.568H26.37v7.26h8.896v3.48H26.37v8.016h11.673v3.69H20.957z",
'greek_capital_zeta' => "M19.884,38.275v-3.69l12.938-18.756h-12.2v-3.568h18.491v3.568L26.177,34.585h12.938v3.69H19.884z"
	,
'greek_capital_eta' => "M18.707,38.275V12.261h5.413v10.564h10.759V12.261h5.414v26.017h-5.414V26.411H24.12v11.864H18.707z
	",
'greek_capital_theta' => "M29.334,38.958c-3.949,0-7.107-1.242-9.476-3.728c-2.367-2.484-3.551-5.794-3.551-9.932
	c0-4.184,1.189-7.506,3.568-9.967s5.59-3.691,9.633-3.691c4.021,0,7.223,1.23,9.606,3.691s3.577,5.766,3.577,9.914
	c0,4.242-1.192,7.588-3.577,10.037C36.729,37.732,33.472,38.958,29.334,38.958z M29.404,35.372c2.319,0,4.157-0.911,5.511-2.733
	s2.03-4.292,2.03-7.409c0-3.023-0.681-5.449-2.039-7.277c-1.359-1.828-3.158-2.742-5.396-2.742c-2.262,0-4.069,0.914-5.423,2.742
	c-1.354,1.828-2.03,4.271-2.03,7.33c0,3.035,0.674,5.476,2.021,7.32C25.425,34.449,27.201,35.372,29.404,35.372z M24.623,26.601
	v-3.586h9.756v3.586H24.623z",
'greek_capital_iota' => "M26.793,38.275V12.261h5.414v26.017h-5.414V38.275z",
'greek_capital_kappa' => "M18.585,38.275V12.261h5.202v12.621l9.949-12.621h4.5l-9.018,11.672l11.196,14.344h-6.768
	L23.786,25.48v12.797h-5.201V38.275z",
'greek_capital_lamda' => "M16.668,38.275L26.793,12.26h5.414l10.125,26.016h-5.556l-7.962-20.46l-7.963,20.46H16.668z",
'greek_capital_mu' => "M16.413,38.275V12.261h7.172l6.258,18.3l6.451-18.3h6.293v26.017h-4.994V18.642l-6.346,17.895h-4.358
	l-6.223-18.158v19.898h-4.253V38.275z",
'greek_capital_nu' => "M18.918,38.275V12.261h4.764L35.74,30.032V12.261h4.342v26.017H35.23L23.26,20.505v17.771H18.918z",
'greek_capital_xi' => "M19.199,38.275v-4.553h20.602v4.553H19.199z M20.184,16.585v-4.324h18.65v4.324H20.184z
	 M21.906,26.728v-3.902h15.188v3.902H21.906z",
'greek_capital_omicron' => "M29.334,38.958c-3.949,0-7.107-1.242-9.476-3.728c-2.367-2.484-3.551-5.794-3.551-9.932
	c0-4.184,1.189-7.506,3.568-9.967s5.59-3.691,9.633-3.691c4.021,0,7.223,1.23,9.606,3.691s3.577,5.766,3.577,9.914
	c0,4.242-1.192,7.588-3.577,10.037C36.729,37.732,33.472,38.958,29.334,38.958z M29.404,35.372c2.319,0,4.157-0.911,5.511-2.733
	s2.03-4.292,2.03-7.409c0-3.023-0.681-5.449-2.039-7.277c-1.359-1.828-3.158-2.742-5.396-2.742c-2.262,0-4.069,0.914-5.423,2.742
	c-1.354,1.828-2.03,4.271-2.03,7.33c0,3.035,0.674,5.476,2.021,7.32C25.425,34.449,27.201,35.372,29.404,35.372z",
'greek_capital_pi' => "M18.707,38.275V12.261h21.586v26.017h-5.414V15.829H24.12v22.446H18.707z",
'greek_capital_rho' => "M20.562,38.275V12.261h9.069c3.164,0,5.423,0.53,6.776,1.591c1.353,1.061,2.029,2.833,2.029,5.317
	c0,2.812-0.904,5.001-2.716,6.565s-4.345,2.347-7.603,2.347h-2.25v10.194H20.562z M25.87,24.513h1.055
	c1.853,0,3.313-0.431,4.387-1.292c1.072-0.861,1.607-2.03,1.607-3.507c0-2.59-1.646-3.885-4.938-3.885h-2.109L25.87,24.513
	L25.87,24.513z",
'greek_capital_sigma' => "M19.156,38.275v-4.289l9.562-8.507l-8.701-9.65v-3.568h19.282v3.568H26.959l8.033,8.895
	l-10.405,9.211h15.257v4.342H19.156V38.275z",
'greek_capital_tau' => "M26.784,38.275V15.829h-9.316v-3.568h24.064v3.568h-9.316v22.446H26.784z",
'greek_capital_upsilon' => "M26.512,38.275v-7.664c0-3.972-0.861-7.411-2.584-10.317c-1.723-2.906-3.768-4.359-6.135-4.359
	v-3.674c3.434,0,6.132,0.854,8.095,2.558c1.963,1.705,3.401,4.456,4.315,8.253c1.066-3.117,2.581-5.64,4.544-7.567
	c1.963-1.927,4.116-3.009,6.46-3.243v3.252c-2.484,0.574-4.648,2.396-6.494,5.467c-1.847,3.071-2.77,6.375-2.77,9.914v7.383h-5.431
	V38.275z",
'greek_capital_phi' => "M26.951,38.275v-3.551c-3.023-0.141-5.443-1.072-7.26-2.795c-1.817-1.723-2.725-3.943-2.725-6.662
	c0-2.73,0.908-4.954,2.725-6.671c1.817-1.717,4.236-2.646,7.26-2.786V12.26h5.098v3.551c3.022,0.141,5.442,1.069,7.26,2.786
	c1.817,1.717,2.726,3.94,2.726,6.671c0,2.719-0.908,4.939-2.726,6.662s-4.235,2.654-7.26,2.795v3.551H26.951z M26.951,19.38
	c-1.594,0.211-2.789,0.809-3.586,1.793c-0.797,0.984-1.195,2.35-1.195,4.096c0,1.758,0.398,3.126,1.195,4.104
	s1.992,1.566,3.586,1.768V19.38z M32.049,19.38v11.761c1.594-0.199,2.789-0.789,3.586-1.768s1.194-2.347,1.194-4.104
	c0-1.746-0.397-3.111-1.194-4.096C34.838,20.188,33.643,19.591,32.049,19.38z",
'greek_capital_chi' => "M18.32,38.275l8.332-12.813l-7.963-13.201H25l5.291,8.754l5.729-8.754h4.379l-7.98,12.271
	l8.262,13.746h-6.293l-5.643-9.299l-6.047,9.299H18.32V38.275z",
'greek_capital_psi' => "M26.785,38.275V27.976c-2.509-0.141-4.339-0.741-5.493-1.802s-1.919-2.839-2.294-5.335l-0.246-1.6
	c-0.211-1.406-0.483-2.326-0.817-2.76s-0.935-0.65-1.802-0.65h-0.229v-3.568h0.334c2.391,0,4.055,0.401,4.991,1.204
	c0.938,0.803,1.629,2.429,2.074,4.878l0.316,1.688c0.315,1.746,0.683,2.918,1.099,3.516c0.416,0.598,1.104,0.955,2.065,1.072V12.261
	h5.432v12.357c0.961-0.117,1.649-0.475,2.065-1.072c0.416-0.597,0.781-1.77,1.098-3.516l0.316-1.688
	c0.445-2.449,1.137-4.075,2.074-4.878c0.938-0.803,2.602-1.204,4.992-1.204h0.334v3.568h-0.229c-0.867,0-1.469,0.217-1.803,0.65
	s-0.605,1.354-0.816,2.76l-0.246,1.6c-0.375,2.496-1.144,4.274-2.303,5.335c-1.16,1.061-2.988,1.661-5.484,1.802v10.3H26.785z",
'greek_capital_omega' => "M15.613,38.309v-3.586h7.312c-2.145-1.595-3.753-3.341-4.825-5.239
	c-1.072-1.898-1.608-3.949-1.608-6.152c0-3.457,1.207-6.27,3.621-8.438s5.543-3.252,9.387-3.252c3.844,0,6.973,1.084,9.387,3.252
	s3.621,4.98,3.621,8.438c0,2.191-0.537,4.236-1.607,6.135c-1.072,1.899-2.682,3.65-4.826,5.256h7.312v3.586h-11.9v-3.586
	c1.758-1.312,3.076-2.886,3.955-4.72s1.318-3.929,1.318-6.284c0-2.637-0.646-4.714-1.941-6.231
	c-1.295-1.517-3.068-2.276-5.318-2.276c-2.25,0-4.022,0.762-5.317,2.285s-1.942,3.604-1.942,6.24c0,2.355,0.439,4.447,1.318,6.275
	c0.879,1.828,2.197,3.398,3.955,4.71v3.586H15.613L15.613,38.309z",
'greek_small_alpha' => "M33.685,26.548c0.469-1.184,0.841-2.402,1.116-3.656c0.274-1.254,0.447-2.549,0.519-3.885h5.237
	c-0.233,1.957-0.696,3.703-1.389,5.238c-0.691,1.535-1.834,3.346-3.428,5.432c2.145,3.88,3.99,6.757,5.537,8.632h-5.783
	c-0.938-1.336-1.934-2.918-2.988-4.746c-2.977,3.457-5.688,5.186-8.139,5.186c-1.969,0-3.567-0.841-4.799-2.521
	c-1.23-1.682-1.846-3.871-1.846-6.565c0-3.129,0.838-5.76,2.514-7.893c1.676-2.133,3.744-3.199,6.205-3.199
	c2.191,0,3.974,1.383,5.344,4.148l1.283,2.619C33.198,25.593,33.403,25.997,33.685,26.548z M30.925,30.607l-0.703-1.458
	c-0.141-0.316-0.328-0.727-0.562-1.23c-0.479-1.055-0.797-1.729-0.948-2.021l-1.091-1.986c-0.516-0.926-1.03-1.389-1.547-1.389
	c-0.819,0-1.509,0.662-2.064,1.986c-0.557,1.324-0.835,2.953-0.835,4.887c0,1.887,0.208,3.299,0.624,4.236s1.046,1.406,1.89,1.406
	C26.905,35.038,28.651,33.562,30.925,30.607z",
'greek_small_beta' => "M20.412,45.251V21.362c0-3.75,0.74-6.562,2.224-8.438s3.712-2.812,6.688-2.812
	c2.228,0,4.005,0.56,5.335,1.679s1.995,2.616,1.995,4.491c0,1.395-0.409,2.654-1.229,3.779s-2.051,2.121-3.691,2.988
	c2.18,0.668,3.867,1.679,5.062,3.032c1.194,1.353,1.793,2.927,1.793,4.72c0,2.262-0.832,4.151-2.496,5.669
	c-1.664,1.519-3.728,2.276-6.188,2.276c-1.358,0-2.789-0.223-4.289-0.668v7.172L20.412,45.251L20.412,45.251z M26.687,22.206h0.439
	c1.229,0,2.265-0.536,3.103-1.608c0.838-1.072,1.257-2.399,1.257-3.981c0-1.078-0.223-1.89-0.668-2.435
	c-0.444-0.545-1.106-0.817-1.985-0.817c-1.078,0-1.885,0.548-2.417,1.644c-0.533,1.096-0.801,2.739-0.801,4.931v14.625
	c1.302,0.621,2.496,0.933,3.586,0.933c1.173,0,2.159-0.442,2.963-1.327c0.803-0.885,1.203-1.972,1.203-3.261
	c0-1.57-0.595-2.889-1.783-3.955c-1.189-1.066-2.663-1.6-4.421-1.6h-0.476V22.206z",
'greek_small_gamma' => "M27.592,36.059l-0.264-0.65c-1.348-3.328-2.76-6.357-4.236-9.088s-3.023-5.168-4.641-7.312h6.188
	c1.852,2.93,3.352,5.801,4.5,8.613l0.949,2.338c0.059,0.129,0.176,0.41,0.352,0.844c1.522-3.691,3.451-7.412,5.783-11.162
	l0.387-0.633h3.938c-1.103,1.453-2.521,3.879-4.254,7.277c-1.734,3.398-3.082,6.387-4.043,8.965c0.68,2.203,1.02,3.867,1.02,4.992
	c0,1.547-0.422,3.217-1.266,5.01h-4.413c-0.715-1.629-1.072-3.082-1.072-4.359C26.521,39.79,26.878,38.18,27.592,36.059z",
'greek_small_delta' => "M26.469,21.204c-2.156-1.207-3.649-2.25-4.481-3.129c-0.832-0.879-1.248-1.84-1.248-2.883
	c0-1.605,0.772-2.854,2.319-3.744c1.547-0.89,3.709-1.336,6.486-1.336c1.969,0,3.82,0.199,5.556,0.598v3.656
	c-1.841-0.668-3.722-1.002-5.644-1.002c-1.172,0-2.051,0.135-2.637,0.404s-0.879,0.668-0.879,1.195c0,0.516,0.562,1.113,1.688,1.793
	l1.652,1.037l1.616,0.984l1.564,0.967c2.355,1.488,4.047,2.991,5.071,4.509s1.538,3.29,1.538,5.317c0,2.708-0.889,4.913-2.663,6.618
	s-4.069,2.559-6.882,2.559c-2.813,0-5.115-0.803-6.908-2.408s-2.689-3.662-2.689-6.17c0-2.027,0.545-3.788,1.635-5.282
	C22.654,23.392,24.289,22.165,26.469,21.204z M29.51,23.313c-1.395,0.797-2.438,1.752-3.129,2.865
	c-0.691,1.113-1.037,2.385-1.037,3.814c0,1.641,0.391,2.968,1.169,3.98c0.779,1.014,1.796,1.521,3.05,1.521
	c1.195,0,2.175-0.521,2.937-1.564s1.143-2.385,1.143-4.024c0-1.478-0.308-2.704-0.923-3.683S31.033,24.274,29.51,23.313z",
'greek_small_epsilon' => "M36.795,34.105v3.357c-2.496,0.855-4.752,1.283-6.768,1.283c-2.332,0-4.219-0.504-5.66-1.512
	s-2.162-2.326-2.162-3.955c0-2.379,1.676-4.207,5.027-5.484c-2.918-0.738-4.377-2.18-4.377-4.324c0-1.523,0.727-2.722,2.18-3.595
	s3.445-1.31,5.977-1.31c1.816,0,3.568,0.17,5.256,0.51v3.234c-1.688-0.34-3.252-0.51-4.692-0.51c-2.344,0-3.516,0.691-3.516,2.074
	c0,1.652,1.928,2.479,5.783,2.479h0.896v3.252h-1.863c-3.504,0-5.256,1.043-5.256,3.129c0,1.815,1.189,2.725,3.568,2.725
	C32.605,35.46,34.475,35.009,36.795,34.105z",
'greek_small_zeta' => "M25.562,18.04h-0.791c-2.355,0-4.6-0.434-6.732-1.301v-4.518c3.094,1.828,6.498,2.859,10.213,3.094
	c1.781-1.547,3.586-2.754,5.414-3.621c1.828-0.867,3.687-1.395,5.571-1.582l1.037,3.041c-1.371,1.395-2.908,2.511-4.613,3.349
	s-3.577,1.397-5.616,1.679c-1.289,2.004-2.256,3.932-2.9,5.783s-0.967,3.621-0.967,5.309c0,1.723,0.46,2.974,1.38,3.752
	c0.92,0.779,2.399,1.17,4.438,1.17h1.758c2.402,0,4.204,0.447,5.405,1.345s1.802,2.241,1.802,4.034c0,1.875-0.782,3.359-2.347,4.456
	c-1.565,1.096-3.684,1.644-6.354,1.644c-0.961,0-2.045-0.111-3.252-0.334v-3.568c1.137,0.293,2.303,0.439,3.498,0.439
	c1.43,0,2.502-0.176,3.218-0.527c0.715-0.351,1.071-0.873,1.071-1.563s-0.302-1.166-0.905-1.425
	c-0.603-0.258-1.696-0.387-3.278-0.387h-1.6c-3.422,0-5.988-0.715-7.699-2.145s-2.566-3.574-2.566-6.434
	c0-1.898,0.401-3.82,1.204-5.766C22.754,22.018,23.957,20.044,25.562,18.04z",
'greek_small_eta' => "M21.405,38.309V24.79c0-2.227-0.381-4.154-1.143-5.783h5.625c0.258,0.902,0.498,2.121,0.721,3.656
	c1.888-2.73,4.078-4.096,6.574-4.096c1.852,0,3.239,0.562,4.166,1.688c0.926,1.126,1.389,2.807,1.389,5.045v19.951h-5.203V26.214
	c0-1.137-0.198-1.989-0.598-2.558c-0.398-0.569-0.996-0.854-1.793-0.854c-1.594,0-3.104,1.103-4.535,3.305v12.199h-5.203V38.309z",
'greek_small_theta' => "M29.359,38.747c-2.941,0-5.241-1.257-6.899-3.771c-1.658-2.515-2.487-5.998-2.487-10.451
	c0-4.57,0.832-8.115,2.496-10.635s4.008-3.779,7.031-3.779c3.012,0,5.353,1.257,7.022,3.771c1.669,2.514,2.505,6.038,2.505,10.573
	c0,4.582-0.839,8.108-2.515,10.582C34.837,37.511,32.453,38.747,29.359,38.747z M25.246,25.792l-0.019,0.756
	c0,2.801,0.378,4.992,1.135,6.574c0.756,1.582,1.802,2.373,3.138,2.373s2.382-0.791,3.138-2.373s1.134-3.773,1.134-6.574
	l-0.018-0.756H25.246z M25.281,22.522h8.438c0-3.047-0.352-5.335-1.055-6.864c-0.703-1.529-1.758-2.294-3.164-2.294
	s-2.461,0.765-3.164,2.294C25.633,17.187,25.281,19.476,25.281,22.522z",
'greek_small_iota' => "M34.703,37.868c-1.396,0.586-2.807,0.879-4.236,0.879c-1.875,0-3.315-0.429-4.324-1.283
	c-0.727-0.608-1.216-1.389-1.468-2.338s-0.378-2.479-0.378-4.588V19.007H29.5v11.849c0,1.641,0.19,2.797,0.571,3.472
	c0.381,0.674,1.027,1.011,1.941,1.011c0.773,0,1.67-0.246,2.689-0.738L34.703,37.868L34.703,37.868z",
'greek_small_kappa' => "M20.932,38.309V19.007h5.202v9.229l1.441-1.828l1.775-2.215c1.815-2.262,3.173-3.691,4.068-4.289
	c0.896-0.598,2.153-0.896,3.771-0.896v3.621l-0.438-0.018c-0.75,0-1.481,0.281-2.197,0.844c-0.715,0.563-1.676,1.605-2.883,3.129
	l-0.879,1.09l7.276,10.635h-5.606l-6.328-9.369v9.369H20.932L20.932,38.309z",
'greek_small_lamda' => "M28.7,25.44l-5.854,12.869h-4.22l7.998-17.543l-1.229-2.76c-0.646-1.453-1.27-2.373-1.872-2.76
	c-0.604-0.387-1.727-0.58-3.366-0.58h-0.369v-4.113h0.527c3.152,0,5.323,0.398,6.513,1.195c1.19,0.797,2.44,2.689,3.753,5.678
	l5.484,12.393c1.478,3.364,2.912,6.193,4.308,8.491h-5.644l-0.422-0.791c-1.09-2.039-2.156-4.248-3.199-6.627L28.7,25.44z",
'greek_small_mu' => "M20.289,45.251V19.007h5.202v11.918c0,1.195,0.199,2.093,0.599,2.689
	c0.398,0.597,1.002,0.896,1.811,0.896c1.57,0,3.082-1.119,4.535-3.357V19.007h5.203v13.535c0,2.238,0.357,4.16,1.072,5.767h-5.625
	c-0.259-0.927-0.476-2.14-0.65-3.64c-1.453,2.647-3.088,3.974-4.904,3.974c-0.797,0-1.477-0.183-2.039-0.545v7.153H20.289z",
'greek_small_nu' => "M27.267,38.309c-0.773-2.613-1.963-5.916-3.568-9.906s-3.012-7.122-4.219-9.396h5.836
	c0.41,0.809,0.949,2.051,1.617,3.727l1.354,3.445c0.914,2.32,1.729,4.635,2.443,6.943l0.229,0.721
	c1.055-1.793,2.032-3.961,2.936-6.504c0.902-2.543,1.354-4.4,1.354-5.572c0-0.926-0.176-1.846-0.527-2.76h4.535
	c0.177,0.609,0.265,1.248,0.265,1.916c0,1.512-0.656,3.894-1.97,7.146c-1.312,3.251-2.993,6.666-5.045,10.24H27.267z",
'greek_small_xi' => "M27.462,23.823c-1.431-0.445-2.566-1.169-3.41-2.171s-1.266-2.13-1.266-3.384
	c0-1.078,0.409-2.209,1.229-3.393c-1.887-0.258-3.674-0.715-5.361-1.371V9.726c2.31,1.195,4.998,2.021,8.068,2.479
	c2.508-1.395,5.004-2.092,7.488-2.092c0.938,0,1.922,0.082,2.953,0.246l0.756,2.109c-1.277,0.938-2.695,1.641-4.254,2.109
	c-1.56,0.468-3.259,0.703-5.099,0.703c-0.526,0.785-0.791,1.635-0.791,2.549c0,1.523,0.627,2.698,1.881,3.524
	c1.255,0.826,3.035,1.239,5.345,1.239h2.268v3.252h-2.127c-2.812,0-4.922,0.416-6.328,1.248s-2.108,2.08-2.108,3.744
	c0,1.125,0.403,1.966,1.213,2.521c0.809,0.557,2.026,0.836,3.655,0.836h1.564c2.402,0,4.204,0.447,5.405,1.345
	s1.802,2.241,1.802,4.034c0,1.875-0.785,3.359-2.355,4.455c-1.569,1.097-3.686,1.645-6.346,1.645c-0.973,0-2.057-0.111-3.252-0.334
	V41.77c1.125,0.293,2.291,0.439,3.498,0.439c1.43,0,2.502-0.176,3.217-0.527c0.715-0.351,1.072-0.873,1.072-1.563
	c0-0.691-0.302-1.166-0.905-1.425c-0.603-0.258-1.702-0.387-3.296-0.387h-1.406c-2.977,0-5.268-0.601-6.873-1.802
	c-1.604-1.2-2.407-2.909-2.407-5.124c0-1.652,0.513-3.108,1.538-4.368C23.854,25.753,25.399,24.69,27.462,23.823z",
'greek_small_omicron' => "M29.368,38.747c-3.013,0-5.405-0.911-7.182-2.733c-1.775-1.822-2.663-4.273-2.663-7.355
	c0-3.117,0.895-5.578,2.682-7.383c1.786-1.805,4.216-2.707,7.285-2.707c3.082,0,5.518,0.902,7.305,2.707s2.682,4.254,2.682,7.348
	c0,3.164-0.896,5.643-2.689,7.436S32.521,38.747,29.368,38.747z M29.456,35.495c2.987,0,4.481-2.291,4.481-6.873
	c0-2.098-0.396-3.756-1.187-4.975s-1.878-1.828-3.262-1.828c-1.37,0-2.451,0.609-3.242,1.828s-1.188,2.889-1.188,5.01
	c0,2.098,0.394,3.762,1.178,4.991C27.022,34.879,28.097,35.495,29.456,35.495z",
'greek_small_pi' => "M21.485,38.309V22.909h-0.352c-1.582,0-3.346,0.867-5.291,2.602v-4.938
	c1.465-1.043,3.463-1.564,5.994-1.564h21.322v3.902H38.5v9.896c0,2.565,0.633,4.399,1.898,5.502h-5.941
	c-0.773-0.974-1.16-2.9-1.16-5.783V22.91h-6.609v15.398H21.485z",
'greek_small_rho' => "M20.438,45.251V32.7c0-4.922,0.756-8.508,2.268-10.758s3.92-3.375,7.226-3.375
	c2.694,0,4.808,0.779,6.337,2.338c1.528,1.559,2.293,3.709,2.293,6.451c0,3.141-0.945,5.751-2.838,7.832
	c-1.894,2.08-4.274,3.119-7.146,3.119c-0.996,0-1.975-0.158-2.936-0.475v7.418L20.438,45.251L20.438,45.251z M25.642,34.124
	c0.901,0.621,1.821,0.933,2.76,0.933c1.44,0,2.628-0.691,3.56-2.074c0.933-1.383,1.397-3.135,1.397-5.256
	c0-1.828-0.354-3.27-1.063-4.324c-0.709-1.054-1.685-1.582-2.927-1.582c-1.395,0-2.364,0.645-2.909,1.934s-0.816,3.58-0.816,6.873
	L25.642,34.124L25.642,34.124z",
'greek_small_final_sigma' => "M27.18,41.771c1.125,0.293,2.291,0.438,3.498,0.438c1.418,0,2.483-0.176,3.198-0.526
	c0.716-0.352,1.072-0.873,1.072-1.564s-0.299-1.166-0.896-1.424c-0.598-0.258-1.693-0.387-3.287-0.387h-1.301
	c-3.199,0-5.6-0.681-7.198-2.039c-1.6-1.359-2.399-3.404-2.399-6.136c0-3.305,1.226-6.059,3.674-8.262
	c2.449-2.203,5.515-3.305,9.193-3.305c1.559,0,3.035,0.141,4.431,0.422v3.516c-1.5-0.457-2.966-0.686-4.396-0.686
	c-2.344,0-4.185,0.688-5.521,2.065s-2.004,3.278-2.004,5.704c0,1.617,0.435,2.789,1.302,3.516c0.866,0.728,2.278,1.09,4.235,1.09
	h1.144c2.401,0,4.204,0.449,5.405,1.346s1.802,2.241,1.802,4.034c0,1.875-0.785,3.36-2.354,4.456
	c-1.57,1.096-3.687,1.644-6.347,1.644c-0.961,0-2.045-0.11-3.252-0.334V41.771z",
'greek_small_sigma' => "M31.073,19.007h10.125v3.691h-5.01c1.043,1.934,1.563,3.885,1.563,5.854
	c0,3.177-0.888,5.669-2.662,7.479c-1.775,1.81-4.217,2.716-7.321,2.716c-3.082,0-5.514-0.902-7.295-2.707
	c-1.781-1.806-2.672-4.267-2.672-7.383c0-3.094,0.888-5.549,2.663-7.365c1.774-1.816,4.175-2.725,7.197-2.725
	C28.647,18.567,29.784,18.714,31.073,19.007z M27.733,35.495c1.488,0,2.607-0.571,3.357-1.714s1.125-2.862,1.125-5.159
	c0-2.098-0.396-3.756-1.188-4.975s-1.878-1.828-3.261-1.828c-1.371,0-2.452,0.609-3.243,1.828s-1.187,2.889-1.187,5.01
	c0,2.098,0.393,3.762,1.178,4.991C25.301,34.879,26.374,35.495,27.733,35.495z",
'greek_small_tau' => "M27.979,38.309c-0.797-1.793-1.194-4.295-1.194-7.507v-8.104h-2.32c-1.604,0-3.07,0.287-4.395,0.861
	v-3.867c1.229-0.457,2.776-0.686,4.641-0.686h14.221v3.691h-6.943v10.037c0,2.297,0.463,4.154,1.389,5.572h-5.397V38.309z",
'greek_small_upsilon' => "M20.87,19.007h5.203v9.281c0,2.776,0.267,4.673,0.8,5.687c0.533,1.015,1.532,1.521,2.997,1.521
	c1.336,0,2.417-0.562,3.243-1.688c0.826-1.127,1.239-2.597,1.239-4.413c0-2.977-1.05-6.439-3.146-10.389h5.062
	c1.241,3.258,1.862,6.428,1.862,9.51c0,3.129-0.806,5.616-2.416,7.461c-1.611,1.847-3.776,2.77-6.496,2.77
	c-2.52,0-4.518-0.691-5.993-2.074c-0.938-0.867-1.564-1.878-1.882-3.031c-0.316-1.154-0.475-2.985-0.475-5.494L20.87,19.007
	L20.87,19.007z",
'greek_small_phi' => "M24.2,19.007v3.252c-1.148,0-2.01,0.41-2.584,1.23c-0.574,0.82-0.861,2.051-0.861,3.691
	c0,2.52,0.489,4.436,1.468,5.748c0.979,1.312,2.446,2.021,4.403,2.127V31.1c0-5.016,0.516-8.268,1.547-9.756
	c1.289-1.852,3.397-2.777,6.328-2.777c2.729,0,4.866,0.753,6.407,2.259c1.541,1.506,2.312,3.595,2.312,6.267
	c0,3.129-1.063,5.701-3.19,7.718c-2.127,2.016-5.006,3.182-8.64,3.498v6.942h-4.764v-6.942c-3.387-0.211-6.041-1.283-7.963-3.218
	c-1.922-1.934-2.883-4.5-2.883-7.699c0-2.789,0.7-4.884,2.101-6.284C19.282,19.708,21.388,19.007,24.2,19.007z M31.39,35.057
	c2.272-0.177,3.981-0.943,5.124-2.304s1.714-3.311,1.714-5.854c0-1.688-0.29-2.956-0.87-3.806c-0.58-0.85-1.443-1.274-2.593-1.274
	c-1.137,0-1.985,0.492-2.549,1.477c-0.563,0.985-0.845,2.455-0.845,4.412l0.019,2.777V35.057z",
'greek_small_chi' => "M26.828,31.839l-2.9-5.221l-0.879-1.6c-1.312-2.32-2.561-4.324-3.744-6.012h5.783
	c1.02,1.477,2.367,3.721,4.043,6.732l0.738,1.336l5.08-8.068h4.289l-7.33,11.672l4.078,7.277l1.266,2.057l1.424,2.303
	c0.354,0.574,0.791,1.254,1.318,2.039l0.58,0.896h-5.871c-1.348-1.969-2.619-4.02-3.814-6.152l-2.003-3.586l-6.064,9.738h-4.395
	L26.828,31.839z",
'greek_small_psi' => "M27.302,45.251v-6.942c-3.738-0.246-6.363-1.22-7.875-2.918c-1.512-1.699-2.268-4.529-2.268-8.491
	v-2.373c0-2.438-0.369-4.277-1.107-5.52h5.133c0.645,1.195,0.967,2.982,0.967,5.361v2.092c0,2.941,0.357,5.007,1.072,6.196
	c0.715,1.188,2.074,1.988,4.078,2.398v-19.3h4.975v19.302c2.016-0.306,3.465-1.1,4.35-2.383c0.887-1.283,1.328-3.231,1.328-5.845
	c0-2.672-0.475-5.279-1.424-7.822h5.062c0.9,2.484,1.354,5.08,1.354,7.787c0,3.539-0.918,6.299-2.752,8.279
	c-1.834,1.979-4.473,3.059-7.918,3.233v6.943L27.302,45.251L27.302,45.251z",
'greek_small_omega' => "M29.503,33.475c-0.798,1.758-1.756,3.075-2.875,3.955c-1.119,0.879-2.398,1.317-3.841,1.317
	c-2.414,0-4.392-0.92-5.933-2.761c-1.541-1.84-2.312-4.2-2.312-7.083c0-3.504,0.896-6.803,2.689-9.896h5.36
	c-2.086,3.387-3.129,6.691-3.129,9.914c0,1.793,0.36,3.259,1.081,4.396c0.722,1.137,1.649,1.705,2.786,1.705
	c0.926,0,1.727-0.391,2.399-1.17c0.673-0.778,1.222-1.947,1.644-3.506c-0.68-1.617-1.02-3.105-1.02-4.465
	c0-1.641,0.352-3.334,1.055-5.08h4.185c0.69,1.746,1.037,3.439,1.037,5.08c0,1.348-0.334,2.836-1.002,4.465
	c0.422,1.559,0.97,2.728,1.644,3.506c0.674,0.779,1.474,1.17,2.399,1.17c1.137,0,2.064-0.568,2.785-1.705s1.082-2.603,1.082-4.396
	c0-3.211-1.043-6.516-3.13-9.914h5.361c1.793,3.105,2.688,6.404,2.688,9.896c0,2.883-0.771,5.244-2.312,7.083
	c-1.541,1.841-3.524,2.761-5.95,2.761c-1.441,0-2.722-0.438-3.841-1.317C31.236,36.55,30.288,35.23,29.503,33.475z",


};

	if ($data->{$letter})
	{	return { id => $letter, d => $data->{$letter} };
	}
	
	if ($letter =~ /^[A-Z]$/)
	{	return { id => $letter, d => $data->{$letter . "_UC"} };
	}
	
	if ($letter =~ /^greek_/)
	{	if ($letter =~ /^greek_[A-Z].+/)
		{	# convert this to greek_capital
			$letter =~ s/greek_/greek_capital_/;
			return { id => $letter, d => $data->{ lc $letter } } || undef;
		}
		# if it doesn't contain small, insert it...
		if ($letter !~ /^greek_small/)
		{	$letter =~ s/greek_/greek_small_/;
			return { id => $letter, d => $data->{ lc $letter } };
		}
	}

	return undef;

}

__END__

=head1 NAME

svg_script.pl - creates an SVG file from input parameters

=head1 SYNOPSIS

svg_script.pl -letter c -letter_colour FF00FF -shape square -shape_colour 000000 -output my_svg_file.svg

=head1 DESCRIPTION

Creates an icon in SVG format from a set of parameters.

=head2 Arguments

-letter, -l    : the letter or glyph

-letter_colour : colour of the letter, as a six character html code,
                 defaults to white if not set

-shape, -s     : the shape of the background image
                 defaults to square if not set

-shape_colour  : colour of the background image, html code
                 defaults to black if not set

-output        : the file to save the image to
                 prints to STDOUT if a file name is not given

The resulting SVG is 60x60px, although the area covered by the shape (and letter)
will be smaller. This is to ensure that the letter is in the same place regardless of the background shape.

Please note that it is possible that the letters may not fit into the shape
completely.

=head2 Letters and Glyphs

The following glyphs and letters are available:

a - z, A - Z, and 0 - 9;

Various other characters:

Glyph	use -letter XXX

!		1_UC

@		2_UC

		3_UC

$		4_UC

%		5_UC

^		6_UC

&		7_UC

*		8_UC

(		9_UC

)		0_UC

-		minus

+		plus

=over

=item Greek alphabet

All letters of the standard Greek alphabet are available. To specify a lowercase
letter, use greek_[letter name]; for an uppercase letter, use greek_capital_[letter name] or greek_[letter name with first letter capitalized].

e.g.

lowercase alpha: -letter greek_alpha

uppercase gamma: -letter greek_capital_gamma  or  -letter greek_Gamma

The letters of the Greek alphabet are:

alpha, beta, gamma, delta, epsilon, zeta, eta, theta, iota, kappa, lamda, mu, nu, xi, omicron, pi, rho, sigma, tau, upsilon, phi, chi, psi, omega


=cut